@@ -7,6 +7,9 @@
 #' @param x An object produced by a call to \code{\link{rp.importance}}.
 #' @param alpha Critical alpha to identify "significant" predictors.
 #' @param sig.only Plot only the significant (<= \code{alpha}) predictors?
+#' @param type character vector listing which importance measures to plot.
+#'   Can be class names or names of overall importance measures 
+#'   (e.g., "MeanDecreaseAccuracy") in the \code{\link{rp.importance}} object.
 #' @param n Plot \code{n} most important predictors.
 #' @param main Main title for plot.
 #' @param ... Optional arguments which will be ignored.
@@ -17,9 +20,22 @@
 #' 
 #' @export plot.rp.importance
 #' @export
-plot.rp.importance <- function(x, alpha = 0.05, sig.only = FALSE, n = NULL, main = NULL, ...) {  
-  imp.list <- lapply(seq(1, ncol(x), 2), function(i) {
-    imp.df <- as.data.frame(x[, c(i, i+1)])
+plot.rp.importance <- function(x, alpha = 0.05, sig.only = FALSE, 
+                               type = NULL, n = NULL, main = NULL, ...) { 
+  cols <- if(is.null(type)) {
+    lapply(seq(1, ncol(x), 2), function(i) c(i, i + 1))
+  } else {
+    type <- unique(gsub(".pval", "", type))
+    not.found <- setdiff(type, colnames(x))
+    if(length(not.found) > 0) {
+      stop(paste("the following columns in 'type' can't be found in 'x':",
+                 paste(not.found, collapse = ", ")
+      ))
+    }
+    lapply(match(type, colnames(x)), function(i) c(i, i + 1))
+  }
+  imp.list <- lapply(cols, function(i) {
+    imp.df <- as.data.frame(x[, i])
     colnames(imp.df) <- c("imp", "pval")
     imp.df$pred <- rownames(imp.df)
     imp.df$is.sig <- factor(imp.df$pval <= alpha)
@@ -29,10 +45,10 @@ plot.rp.importance <- function(x, alpha = 0.05, sig.only = FALSE, n = NULL, main
     if(sig.only) imp.df <- imp.df[as.logical(imp.df$is.sig), ]
     if(!is.null(n) & is.numeric(n)) imp.df <- imp.df[1:min(n, nrow(imp.df)), ]
     with(imp.df, ggplot(imp.df, aes(reorder(pred, imp), imp)) + 
-      geom_bar(aes(fill = is.sig), stat = "identity") +
-      labs(title = colnames(x)[i], x = "Importance", y = "") + coord_flip() +
-      theme(legend.position = "none") +
-      scale_fill_manual(values = c("FALSE" = "black", "TRUE" = "red"))
+           geom_bar(aes(fill = is.sig), stat = "identity") +
+           labs(title = colnames(x)[i], x = "", y = "Importance") + coord_flip() +
+           theme(legend.position = "none") +
+           scale_fill_manual(values = c("FALSE" = "black", "TRUE" = "red"))
     )
   })
   suppressWarnings(do.call(gridExtra::grid.arrange, c(imp.list, main = main)))
